==> maintenance_notifier-1.0.0.tar.gz: maintenance_notifier/src/Form/MaintenanceNotifierConfigForm.php <==
<?php

namespace Drupal\maintenance_notifier\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\Role;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configuration form for Maintenance Notifier.
 */
class MaintenanceNotifierConfigForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new ContentAccessAdminSettingsForm.
   *
   *  @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The EntityTypeManager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['maintenance_notifier.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'maintenance_notifier_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('maintenance_notifier.settings');

    // Time threshold.
    $form['time_threshold'] = [
      '#type' => 'number',
      '#title' => $this->t('Time threshold in minutes'),
      '#default_value' => $config->get('time_threshold') ?? 15,
      '#description' => $this->t('Number of minutes the site must be in maintenance mode before sending an email.'),
      '#required' => TRUE,
    ];

    // Notification emails.
    $form['notification_email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Notification emails'),
      '#default_value' => $config->get('notification_email'),
      '#description' => $this->t('Comma-separated list of email addresses to send notifications to. Leave blank to use user roles.'),
    ];

    // User roles.
    $roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
    // Exclude anonymous role.
    unset($roles['anonymous']);

    $roles = array_map(function (Role $role) {
      return $role->label();
    }, $roles);

    $form['notification_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('User roles'),
      '#options' => $roles,
      '#default_value' => $config->get('notification_roles') ?? [],
      '#description' => $this->t('Roles to send the notification to if no email addresses are specified.'),
    ];

    // Email subject.
    $form['email_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email subject'),
      '#default_value' => $config->get('email_subject') ?? $this->t('Maintenance Mode Notification'),
      '#description' => $this->t('Subject of the notification email. You can use tokens.'),
      '#required' => TRUE,
    ];

    // Email body.
    $form['email_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Email body'),
      '#default_value' => $config->get('email_body') ?? $this->t('The site has been in maintenance mode for [duration].'),
      '#description' => $this->t('Body of the notification email. You can use tokens.<br />Use <strong>[duration]</strong> to display the time the site has been in maintenance mode.'),
      '#required' => TRUE,
    ];

    // Token browser integration.
    $form['token_tree_link'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => ['site', 'user'],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('maintenance_notifier.settings')
      ->set('time_threshold', $form_state->getValue('time_threshold'))
      ->set('notification_email', $form_state->getValue('notification_email'))
      ->set('notification_roles', array_filter($form_state->getValue('notification_roles')))
      ->set('email_subject', $form_state->getValue('email_subject'))
      ->set('email_body', $form_state->getValue('email_body'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}

==> maintenance_notifier-1.0.1.tar.gz: maintenance_notifier/src/Form/MaintenanceNotifierConfigForm.php <==
<?php

namespace Drupal\maintenance_notifier\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\Role;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configuration form for Maintenance Notifier.
 */
class MaintenanceNotifierConfigForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new ContentAccessAdminSettingsForm.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The EntityTypeManager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['maintenance_notifier.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'maintenance_notifier_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('maintenance_notifier.settings');

    // Time threshold.
    $form['time_threshold'] = [
      '#type' => 'number',
      '#title' => $this->t('Time threshold in minutes'),
      '#default_value' => $config->get('time_threshold') ?? 15,
      '#description' => $this->t('Number of minutes the site must be in maintenance mode before sending an email.'),
      '#required' => TRUE,
    ];

    // Notification emails.
    $form['notification_email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Notification emails'),
      '#default_value' => $config->get('notification_email'),
      '#description' => $this->t('Comma-separated list of email addresses to send notifications to. Leave blank to use user roles.'),
    ];

    // User roles.
    $roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
    // Exclude anonymous role.
    unset($roles['anonymous']);

    $roles = array_map(function (Role $role) {
      return $role->label();
    }, $roles);

    $form['notification_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('User roles'),
      '#options' => $roles,
      '#default_value' => $config->get('notification_roles') ?? [],
      '#description' => $this->t('Roles to send the notification to if no email addresses are specified.'),
    ];

    // Email subject.
    $form['email_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email subject'),
      '#default_value' => $config->get('email_subject') ?? $this->t('[[site:name]] Maintenance Mode Notification'),
      '#description' => $this->t('Subject of the notification email. You can use tokens.'),
      '#required' => TRUE,
    ];

    // Email body.
    $form['email_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Email body'),
      '#default_value' => $config->get('email_body') ?? $this->t('The site has been in maintenance mode for [duration].
Environment: [site:url]'),
      '#description' => $this->t('Body of the notification email. You can use tokens.<br />Use <strong>[duration]</strong> to display the time the site has been in maintenance mode.'),
      '#required' => TRUE,
    ];

    // Token browser integration.
    $form['token_tree_link'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => ['site', 'user'],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('maintenance_notifier.settings')
      ->set('time_threshold', $form_state->getValue('time_threshold'))
      ->set('notification_email', $form_state->getValue('notification_email'))
      ->set('notification_roles', array_filter($form_state->getValue('notification_roles')))
      ->set('email_subject', $form_state->getValue('email_subject'))
      ->set('email_body', $form_state->getValue('email_body'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
